@@ -1,5 +1,6 @@
 from __future__ import annotations
 import operator
+import re
 from decimal import Decimal
 from heapq import merge
 from math import ceil, floor, inf, isinf, isnan
@@ -17,6 +18,17 @@ SupportsSelf = TypeVar("SupportsSelf", bound="SupportsInterval")
 
 NOT_REAL = "could not interpret {} as a real value"
 
+FSTRING_FORMATTER = re.compile(
+    "(?P<fill>.*?)"
+    "(?P<align>[<>=^]?)"
+    "(?P<sign>[+ -]?)"
+    "(?P<alternate>[#]?)"
+    "(?P<width>[0-9]*)"
+    "(?P<group>[_,]?)"
+    "(?P<precision>(?:[.][0-9]+)?)"
+    "(?P<dtype>[bcdeEfFgGnosxX%]?)"
+)
+
 
 class SupportsInterval(Protocol):
 
@@ -173,20 +185,31 @@ class Interval:
             return NotImplemented
 
     def __format__(self: Self, specifier: str, /) -> str:
+        match = FSTRING_FORMATTER.fullmatch(specifier)
+        if match is None:
+            # Invalid specifier, raise an error.
+            f"{0.0:{specifier}}"
+            raise TypeError(f"invalid specifier, got {specifier!r}")
+        fill, align, sign, alternate, width, group, precision, dtype = match.groups()
         if len(self._endpoints) == 0:
-            return "interval[()]"
-        else:
-            if not specifier.endswith((*"bcdeEfFgGnosxX%",)):
-                specifier += "g"
-            iterator = iter(self._endpoints)
-            bounds = ", ".join([
-                ":".join([
-                    f"{-0.0:{specifier}}" if lower == 0.0 else "" if isinf(lower) and lower < 0.0 else f"{lower:{specifier}}",
-                    f"{0.0:{specifier}}" if upper == 0.0 else "" if isinf(upper) and upper > 0.0 else f"{upper:{specifier}}",
-                ])
-                for lower, upper in zip(iterator, iterator)
+            return "interval()"
+        if dtype == "":
+            dtype = "g"
+            if precision == "":
+                precision = ".17"
+        specifier = f"{fill}{align}{sign}{alternate}{width}{group}{precision}{dtype}"
+        iterator = iter(self._endpoints)
+        if self.size == 0:
+            points = ", ".join([f"{U:{specifier}}" for _, U in zip(iterator, iterator)])
+            return f"interval({points})"
+        bounds = ", ".join([
+            ":".join([
+                f"{-0.0:{specifier}}" if lower == 0.0 else "" if isinf(lower) and lower < 0.0 else f"{lower:{specifier}}",
+                f"{0.0:{specifier}}" if upper == 0.0 else "" if isinf(upper) and upper > 0.0 else f"{upper:{specifier}}",
             ])
-            return f"interval[{bounds}]"
+            for lower, upper in zip(iterator, iterator)
+        ])
+        return f"interval[{bounds}]"
 
     @classmethod
     def __fsum__(cls: Type[Self], intervals: list[Interval]) -> Self:
@@ -322,7 +345,7 @@ class Interval:
                 *[(x.minimum, x.maximum) for x in other.sub_intervals],
             )
         elif isinstance(other, get_args(RealLike)):
-            if isinstance(other, SupportsFloat):
+            if isinstance(other, SupportsIndex):
                 other = operator.index(other)
             return type(self)(*[(x.minimum, x.maximum) for x in self.sub_intervals], fpur.float_split(other))
         else:
@@ -745,7 +768,11 @@ class Interval:
 
     @property
     def size(self: Self, /) -> float:
-        return sum(interval.maximum - interval.minimum for interval in self.sub_intervals)
+        return sum(
+            interval.maximum - interval.minimum
+            for interval in self.sub_intervals
+            if interval.minimum != interval.maximum
+        )
 
     @property
     def sub_intervals(self: Self, /) -> Iterator[Self]:
