@@ -2,7 +2,7 @@ import math
 from collections.abc import Callable, Iterator
 from itertools import chain
 from math import exp, log, sqrt
-from typing import Iterable, Iterator, Optional, TypeVar
+from typing import Iterable, Iterator, Literal, Optional, TypeVar
 
 from .interval import Interval
 
